@@ -3,10 +3,12 @@ from __future__ import absolute_import, unicode_literals, division
 import six
 import operator
 from functools import partial
+from collections import Iterable
 from copy import deepcopy
 from six.moves import map, reduce
 from armet.exceptions import ImproperlyConfigured
 from armet.query import parser, Query, QuerySegment, constants
+from armet.http.exceptions import BadRequest
 from sqlalchemy.exc import InvalidRequestError
 import sqlalchemy as sa
 
@@ -240,6 +242,15 @@ class ModelResource(object):
             if value is not None:
                 attribute.set(target, value)
 
+        # Iterate through all write-able relations and set each one.
+        for name, relation in six.iteritems(self.relationships):
+            if relation.write:
+                # Set each one on the target.
+                value = data.get(name)
+                if value is not None:
+                    # FIXME: Use some deferred thing that is not `setattr`.
+                    setattr(target, relation.key, value)
+
         # Add the target to the session.
         self.session.add(target)
         self.session.flush()
@@ -261,6 +272,13 @@ class ModelResource(object):
             # Set each one on the target.
             attribute.set(target, data.get(name))
 
+        # Iterate through all write-able relations and set each one.
+        for name, relation in six.iteritems(self.relationships):
+            if relation.write:
+                # Set each one on the target.
+                # FIXME: Use some deferred thing that is not `setattr`.
+                setattr(target, relation.key, data.get(name))
+
         # Flush the target and expire attributes.
         self.session.flush()
 
@@ -284,9 +302,45 @@ class ModelResource(object):
         # Remove the object from the session.
         self.session.delete(target)
 
+    def _resolve_relation(self, target):
+        # Resolve the relationship key.
+        key = None
+        related = type(self)._related_models
+        res_clss = type(target),
+        while res_clss:
+            res_cls_next = []
+            for res_cls in res_clss:
+                print('check', res_cls, related)
+                if res_cls in related:
+                    print('key')
+                    key = self.relationships[related[res_cls]].key
+                    break
+
+                if res_cls.__bases__:
+                    res_cls_next.extend(res_cls.__bases__)
+
+            else:
+                # Nope; continue
+                res_clss = res_cls_next
+                continue
+
+            # Able to link
+            break
+
+        else:
+            # Not able to link
+            return None
+
+        # Able to link
+        return key
+
     def relate(self, target, other):
         # Resolve the relationship key.
-        key = self.relationships[type(self)._related_models[type(other)]].key
+        key = self._resolve_relation(other)
+        if not key:
+            raise BadRequest({
+                '__all__': "Unable to link a '%s' to a '%s'." % (
+                    type(target).__name__, type(other).__name__)})
 
         # Grab the set_ in question.
         set_ = getattr(target, key)
@@ -307,7 +361,11 @@ class ModelResource(object):
 
     def unrelate(self, target, other):
         # Resolve the relationship key.
-        key = self.relationships[type(self)._related_models[type(other)]].key
+        key = self._resolve_relation(other)
+        if not key:
+            raise BadRequest({
+                '__all__': "Unable to link a '%s' to a '%s'." % (
+                    type(target).__name__, type(other).__name__)})
 
         # Grab the set_ in question.
         set_ = getattr(target, key)
@@ -333,10 +391,30 @@ class ModelResource(object):
         # Build the related items.
         qs = set_
 
-        if self.request.user:
-            # Filter the queryset by asserting authorization.
-            qs = resource.meta.authorization.filter(
-                self.request.user, 'read', resource, qs)
+        if isinstance(qs, Iterable):
+            if self.request.user:
+                # Filter the queryset by asserting authorization.
+                qs = resource.meta.authorization.filter(
+                    self.request.user, 'read', resource, qs)
+
+        else:
+            # Ensure we can access this.
+            authz = self.meta.authorization
+            if not authz.is_authorized(
+                    self.request.user, 'read', resource, qs):
+                authz.unauthorized()
 
         # Return the queryset.
         return qs
+
+    def clean_related(self, relation, value):
+        # Grab the model in question.
+        model = relation.resource.meta.model
+
+        # Attempt to build a query to `get` the model.
+        target = self.session.query(model).get(value)
+        if target is not None:
+            # Found a target from the value.
+            return target
+
+        # Found nothing.
