@@ -138,7 +138,7 @@ class ManagedResource(base.Resource):
 
     def item_prepare(self, item):
         # If we are the root resource, clear the map.
-        if self.request._resource.__class__ is type(self):
+        if isinstance(self, self.request._resource.__class__):
             self.request._embed_related.clear()
 
         # We've started doing this one.
@@ -186,8 +186,11 @@ class ManagedResource(base.Resource):
             # Prepare and add to the attribute.
             obj[key] = related.prepare(related_items)
 
-        # We're done doing this one.
-        self.request._embed_related.remove(type(self))
+        # TODO: Remove all that we are.
+        self.request._embed_related = {
+            x for x in self.request._embed_related
+            if not isinstance(self, x)
+        }
 
         # Return the resultant object.
         return obj
@@ -271,6 +274,22 @@ class ManagedResource(base.Resource):
 
             obj[name] = value
 
+        # Iterate through write-able relations
+        for name, relation in six.iteritems(self.relationships):
+            if relation.write:
+                value = item.get(name)
+                try:
+                    value = self.clean_related(relation, value)
+                    obj[name] = value
+
+                except (ValueError, AssertionError) as ex:
+                    self._errors[attribute.name] = [str(ex)]
+                    value = None
+
+                except ValidationError as ex:
+                    self._errors[attribute.name] = ex.errors
+                    value = None
+
         return obj
 
     @property
